# Charles Kurzman, analysis of Carnegie Mellon University Delphi COVID-19 survey data

library(ggplot2)
library(readxl)
library(tidyverse)

# Open csv
setwd("c:/")

d <- read.csv("2020-10.csv.gz", stringsAsFactors = FALSE)

# Mask wearing
# C14 In the past 5 days, how often did you wear a mask when in public?
# All the time (1)
# Most of the time (2)
# Some of the time (3)
# A little of the time (4)
# None of the time (5)
# I have not been in public during the past 5 days (6)
table(d$C14, useNA="always")
prop.table(table(d$C14, useNA="always"))
d$MaskWearing <- d$C14
d$MaskWearing[d$MaskWearing>1] <- 0
d$MaskWearing[d$MaskWearing==1] <- 100

# A3. Zip code to county, from https://www.kaggle.com/danofer/zipcodes-county-fips-crosswalk
d$ZIP <- as.integer(d$A3)
zip <- read.csv("ZIP-COUNTY-FIPS_2017-06.csv", stringsAsFactors = FALSE)
zip <- zip[!duplicated(zip$ZIP),]
dcounty <- merge(d, zip)
dcounty <- select(dcounty, weight, MaskWearing, knowsomeone, STCOUNTYFP)
dcounty$Respondents <- 1

# Weighted means by county:
dcountymean <- dcounty %>%
  group_by(STCOUNTYFP) %>% 
  summarise(weighted.mean(MaskWearing, weight, na.rm=TRUE), sum(Respondents))

names(dcountymean)[1] <- "FIPS"
names(dcountymean)[2] <- "MaskWearing"
names(dcountymean)[3] <- "Respondents"
dcountymean <- dcountymean[dcountymean$Respondents>100,]

# 2020 election results, from https://github.com/kjhealy/us_elections_2020_csv/blob/master/README.md
election <- read_xlsx("kjhealy-2020-election-results.xlsx")
election <- subset(election, race=="President")
election <- subset(election, id != 0)
election$votetotal <- as.numeric(election$votes)
election <- election[,c("lname","fips5","votetotal")]
election <- election %>% group_by(fips5, lname) %>% summarise_all(sum)

election2 <- pivot_wider(election, names_from = lname, fips5, values_from = votetotal)
election2 <- election2[,1:6]
election2$VoteTotal <- rowSums(election2[,-1], na.rm=TRUE)
election2$fips5 <- as.integer(election2$fips5)
election2 <- election2[,c("fips5","Biden","Trump","VoteTotal")]

# Merge with election results
de <- merge(dcountymean, election2, by.x="FIPS", by.y="fips5")

# Add county population, from https://www.census.gov/data/datasets/time-series/demo/popest/2010s-counties-total.html#par_textimage_70769902
cpop <- read.csv("zipcodes/co-est2019-alldata.csv", stringsAsFactors = FALSE)
cpop$fips5 <- (cpop$STATE*1000) + cpop$COUNTY
cpop <- cpop[,names(cpop) %in% c("fips5", "POPESTIMATE2019")]
de <- merge(de, cpop, by.x="FIPS", by.y="fips5")

de$BidenVoteShare <- 100*de$Biden/de$VoteTotal
de$TrumpVoteShare <- 100*de$Trump/de$VoteTotal

# Biden votes by mask-wearing
ggplot(de, aes(x=de$MaskWearing, y=de$BidenVoteShare)) +
  geom_point(size=de$POPESTIMATE2019/500000, alpha=0.75) + geom_segment(aes(x=0,xend=max(MaskWearing),y=50,yend=50), color="black", size=0.3) + 
  theme(panel.background=element_blank()) + theme(legend.position = "none") +
  expand_limits(x = 0) + expand_limits(x = 100) +
  expand_limits(y = 0) + expand_limits(y = 100) +
  annotate(geom="text", x=0, y=100, label="Mask-wearing and Biden vote-share, by county", hjust="left", size=5) + 
  ylab("Percent of votes for Biden, November 2020") + xlab("Percent of survey respondents reporting they wear a mask all the time when in public, October 2020") +
  labs(caption="Charles Kurzman, UNC-Chapel Hill, February 8, 2021.\nSurvey data: Delphi Research Group, Carnegie Mellon University.\nCounties with 100 or more survey respondents. Point-size proportional to population.", color="black")

ggsave("cKurzman-Mask-Wearing-and-Biden-Vote-Share-2021-02-08.png", dpi=300, height=4, width=8)

write.csv(de, "Kurzman-Mask-Wearing-and-Biden-Vote-Share-Data-by-County-2021-02-08.csv")
